/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

interface nsIURI;
interface nsIArray;
interface nsICRLInfo;

%{C++
#define NS_CRLMANAGER_CID { /* 5b256c10-22d8-4109-af92-1253035e9fcb */ \
    0x5b256c10, \
    0x22d8, \
    0x4109, \
    {0xaf, 0x92, 0x12, 0x53, 0x03, 0x5e, 0x9f, 0xcb} \
  }

#define NS_CRLMANAGER_CONTRACTID "@mozilla.org/security/crlmanager;1"
%}



[scriptable, uuid(486755db-627a-4678-a21b-f6a63bb9c56a)]
interface nsICRLManager : nsISupports {
  /*
   * importCrl
   *
   * Import a CRL into the certificate database.
   */
  void importCrl([array, size_is(length)] in octet data,
                 in unsigned long length,
                 in nsIURI uri,
                 in unsigned long type,
                 in boolean doSilentDownload,
                 in wstring crlKey);

  
  /*
   * update crl from url
   * update an existing crl from the last fetched url. Needed for the update
   * button in crl manager
   */
  boolean updateCRLFromURL(in wstring url, in wstring key);


  /*
   * getCrls
   *
   * Get a list of Crl entries in the DB.
   */
  nsIArray getCrls();

  /*
   * deleteCrl
   *
   * Delete the crl.
   */
  void deleteCrl(in unsigned long crlIndex);


  /* This would reschedule the autoupdate of crls with auto update enable.
   * Most likely to be called when update prefs are changed, or when a crl
   * is deleted, etc. However, this might not be the most relevant place for
   * this api, but unless we have a separate crl handler object....
   */
  void rescheduleCRLAutoUpdate();


  const unsigned long TYPE_AUTOUPDATE_TIME_BASED     = 1;
  const unsigned long TYPE_AUTOUPDATE_FREQ_BASED     = 2;

  wstring computeNextAutoUpdateTime(in nsICRLInfo info,
                                    in unsigned long autoUpdateType,
                                    in double noOfDays);
};
